

## <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/column.html" target="_blank">pyspark.sql.Column</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.asc_nulls_first.html" target="_blank">asc_nulls_first</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.asc_nulls_first&body=Please+implement+feature+%5Bpyspark.sql.Column.asc_nulls_first%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.asc_nulls_first.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.asc.html" target="_blank">asc</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.asc&body=Please+implement+feature+%5Bpyspark.sql.Column.asc%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.asc.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.alias.html" target="_blank">alias</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.between.html" target="_blank">between</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.between&body=Please+implement+feature+%5Bpyspark.sql.Column.between%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.between.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.asc_nulls_last.html" target="_blank">asc_nulls_last</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.asc_nulls_last&body=Please+implement+feature+%5Bpyspark.sql.Column.asc_nulls_last%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.asc_nulls_last.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.bitwiseAND.html" target="_blank">bitwiseAND</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.bitwiseAND&body=Please+implement+feature+%5Bpyspark.sql.Column.bitwiseAND%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.bitwiseAND.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.astype.html" target="_blank">astype</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.astype&body=Please+implement+feature+%5Bpyspark.sql.Column.astype%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.astype.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.bitwiseOR.html" target="_blank">bitwiseOR</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.bitwiseOR&body=Please+implement+feature+%5Bpyspark.sql.Column.bitwiseOR%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.bitwiseOR.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.cast.html" target="_blank">cast</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.bitwiseXOR.html" target="_blank">bitwiseXOR</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.bitwiseXOR&body=Please+implement+feature+%5Bpyspark.sql.Column.bitwiseXOR%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.bitwiseXOR.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.contains.html" target="_blank">contains</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.contains&body=Please+implement+feature+%5Bpyspark.sql.Column.contains%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.contains.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.desc.html" target="_blank">desc</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.desc&body=Please+implement+feature+%5Bpyspark.sql.Column.desc%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.desc.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.desc_nulls_first.html" target="_blank">desc_nulls_first</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.desc_nulls_first&body=Please+implement+feature+%5Bpyspark.sql.Column.desc_nulls_first%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.desc_nulls_first.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.desc_nulls_last.html" target="_blank">desc_nulls_last</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.desc_nulls_last&body=Please+implement+feature+%5Bpyspark.sql.Column.desc_nulls_last%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.desc_nulls_last.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.dropFields.html" target="_blank">dropFields</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.dropFields&body=Please+implement+feature+%5Bpyspark.sql.Column.dropFields%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.dropFields.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.endswith.html" target="_blank">endswith</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.endswith&body=Please+implement+feature+%5Bpyspark.sql.Column.endswith%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.endswith.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.getField.html" target="_blank">getField</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.getField&body=Please+implement+feature+%5Bpyspark.sql.Column.getField%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.getField.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.getItem.html" target="_blank">getItem</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.getItem&body=Please+implement+feature+%5Bpyspark.sql.Column.getItem%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.getItem.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.ilike.html" target="_blank">ilike</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.ilike&body=Please+implement+feature+%5Bpyspark.sql.Column.ilike%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.ilike.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.isNotNull.html" target="_blank">isNotNull</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.isNull.html" target="_blank">isNull</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.isNull&body=Please+implement+feature+%5Bpyspark.sql.Column.isNull%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.isNull.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.isin.html" target="_blank">isin</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.like.html" target="_blank">like</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.like&body=Please+implement+feature+%5Bpyspark.sql.Column.like%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.like.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.eqNullSafe.html" target="_blank">eqNullSafe</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.eqNullSafe&body=Please+implement+feature+%5Bpyspark.sql.Column.eqNullSafe%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.eqNullSafe.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.over.html" target="_blank">over</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.over&body=Please+implement+feature+%5Bpyspark.sql.Column.over%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.over.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.rlike.html" target="_blank">rlike</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.name.html" target="_blank">name</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.name&body=Please+implement+feature+%5Bpyspark.sql.Column.name%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.name.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.startswith.html" target="_blank">startswith</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.startswith&body=Please+implement+feature+%5Bpyspark.sql.Column.startswith%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.startswith.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.substr.html" target="_blank">substr</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.substr&body=Please+implement+feature+%5Bpyspark.sql.Column.substr%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.substr.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.when.html" target="_blank">when</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.when&body=Please+implement+feature+%5Bpyspark.sql.Column.when%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.when.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.otherwise.html" target="_blank">otherwise</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.otherwise&body=Please+implement+feature+%5Bpyspark.sql.Column.otherwise%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.otherwise.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Column.withField.html" target="_blank">withField</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Column.withField&body=Please+implement+feature+%5Bpyspark.sql.Column.withField%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Column.withField.html%29' target='_blank'>request feature :simple-github:</a>)


## <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/data_types.html" target="_blank">pyspark.sql.types</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.types.ArrayType.html" target="_blank">ArrayType</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.types.ArrayType&body=Please+implement+feature+%5Bpyspark.sql.types.ArrayType%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.types.ArrayType.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.types.BinaryType.html" target="_blank">BinaryType</a>
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.types.ByteType.html" target="_blank">ByteType</a>
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.types.DataType.html" target="_blank">DataType</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.types.CharType.html" target="_blank">CharType</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.types.CharType&body=Please+implement+feature+%5Bpyspark.sql.types.CharType%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.types.CharType.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.types.DateType.html" target="_blank">DateType</a>
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.types.DecimalType.html" target="_blank">DecimalType</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.types.DayTimeIntervalType.html" target="_blank">DayTimeIntervalType</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.types.DayTimeIntervalType&body=Please+implement+feature+%5Bpyspark.sql.types.DayTimeIntervalType%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.types.DayTimeIntervalType.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.types.DoubleType.html" target="_blank">DoubleType</a>
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.types.FloatType.html" target="_blank">FloatType</a>
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.types.IntegerType.html" target="_blank">IntegerType</a>
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.types.LongType.html" target="_blank">LongType</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.types.MapType.html" target="_blank">MapType</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.types.MapType&body=Please+implement+feature+%5Bpyspark.sql.types.MapType%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.types.MapType.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.types.NullType.html" target="_blank">NullType</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.types.NullType&body=Please+implement+feature+%5Bpyspark.sql.types.NullType%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.types.NullType.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.types.BooleanType.html" target="_blank">BooleanType</a>
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.types.ShortType.html" target="_blank">ShortType</a>
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.types.StructType.html" target="_blank">StructType</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.types.TimestampNTZType.html" target="_blank">TimestampNTZType</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.types.TimestampNTZType&body=Please+implement+feature+%5Bpyspark.sql.types.TimestampNTZType%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.types.TimestampNTZType.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.types.TimestampType.html" target="_blank">TimestampType</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.types.YearMonthIntervalType.html" target="_blank">YearMonthIntervalType</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.types.YearMonthIntervalType&body=Please+implement+feature+%5Bpyspark.sql.types.YearMonthIntervalType%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.types.YearMonthIntervalType.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.types.StringType.html" target="_blank">StringType</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.types.VarcharType.html" target="_blank">VarcharType</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.types.VarcharType&body=Please+implement+feature+%5Bpyspark.sql.types.VarcharType%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.types.VarcharType.html%29' target='_blank'>request feature :simple-github:</a>)


## <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/dataframe.html" target="_blank">pyspark.sql.DataFrame</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.agg.html" target="_blank">agg</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.agg&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.agg%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.agg.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.alias.html" target="_blank">alias</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.approxQuantile.html" target="_blank">approxQuantile</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.approxQuantile&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.approxQuantile%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.approxQuantile.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.cache.html" target="_blank">cache</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.cache&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.cache%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.cache.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.coalesce.html" target="_blank">coalesce</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.coalesce&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.coalesce%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.coalesce.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.checkpoint.html" target="_blank">checkpoint</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.checkpoint&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.checkpoint%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.checkpoint.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.colRegex.html" target="_blank">colRegex</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.colRegex&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.colRegex%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.colRegex.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.collect.html" target="_blank">collect</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.collect&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.collect%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.collect.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.corr.html" target="_blank">corr</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.corr&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.corr%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.corr.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.cov.html" target="_blank">cov</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.cov&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.cov%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.cov.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.count.html" target="_blank">count</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.count&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.count%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.count.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.createGlobalTempView.html" target="_blank">createGlobalTempView</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.createGlobalTempView&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.createGlobalTempView%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.createGlobalTempView.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.createOrReplaceGlobalTempView.html" target="_blank">createOrReplaceGlobalTempView</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.createOrReplaceGlobalTempView&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.createOrReplaceGlobalTempView%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.createOrReplaceGlobalTempView.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.createOrReplaceTempView.html" target="_blank">createOrReplaceTempView</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.createOrReplaceTempView&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.createOrReplaceTempView%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.createOrReplaceTempView.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.createTempView.html" target="_blank">createTempView</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.createTempView&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.createTempView%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.createTempView.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.crossJoin.html" target="_blank">crossJoin</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.crossJoin&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.crossJoin%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.crossJoin.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.cube.html" target="_blank">cube</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.cube&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.cube%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.cube.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.describe.html" target="_blank">describe</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.describe&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.describe%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.describe.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.crosstab.html" target="_blank">crosstab</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.crosstab&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.crosstab%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.crosstab.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.distinct.html" target="_blank">distinct</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.distinct&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.distinct%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.distinct.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.drop.html" target="_blank">drop</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.drop&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.drop%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.drop.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.dropDuplicates.html" target="_blank">dropDuplicates</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.dropDuplicates&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.dropDuplicates%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.dropDuplicates.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.dropDuplicatesWithinWatermark.html" target="_blank">dropDuplicatesWithinWatermark</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.dropDuplicatesWithinWatermark&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.dropDuplicatesWithinWatermark%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.dropDuplicatesWithinWatermark.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.drop_duplicates.html" target="_blank">drop_duplicates</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.drop_duplicates&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.drop_duplicates%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.drop_duplicates.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.dropna.html" target="_blank">dropna</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.dropna&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.dropna%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.dropna.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.exceptAll.html" target="_blank">exceptAll</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.exceptAll&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.exceptAll%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.exceptAll.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.explain.html" target="_blank">explain</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.explain&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.explain%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.explain.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.fillna.html" target="_blank">fillna</a>
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.filter.html" target="_blank">filter</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.first.html" target="_blank">first</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.first&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.first%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.first.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.foreachPartition.html" target="_blank">foreachPartition</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.foreachPartition&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.foreachPartition%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.foreachPartition.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.freqItems.html" target="_blank">freqItems</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.freqItems&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.freqItems%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.freqItems.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.foreach.html" target="_blank">foreach</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.foreach&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.foreach%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.foreach.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.groupBy.html" target="_blank">groupBy</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.head.html" target="_blank">head</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.head&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.head%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.head.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.hint.html" target="_blank">hint</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.hint&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.hint%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.hint.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.inputFiles.html" target="_blank">inputFiles</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.inputFiles&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.inputFiles%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.inputFiles.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.intersectAll.html" target="_blank">intersectAll</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.intersectAll&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.intersectAll%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.intersectAll.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.isEmpty.html" target="_blank">isEmpty</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.isEmpty&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.isEmpty%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.isEmpty.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.intersect.html" target="_blank">intersect</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.intersect&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.intersect%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.intersect.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.isLocal.html" target="_blank">isLocal</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.isLocal&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.isLocal%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.isLocal.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.join.html" target="_blank">join</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.limit.html" target="_blank">limit</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.limit&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.limit%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.limit.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.mapInArrow.html" target="_blank">mapInArrow</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.mapInArrow&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.mapInArrow%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.mapInArrow.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.localCheckpoint.html" target="_blank">localCheckpoint</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.localCheckpoint&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.localCheckpoint%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.localCheckpoint.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.melt.html" target="_blank">melt</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.melt&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.melt%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.melt.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.observe.html" target="_blank">observe</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.observe&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.observe%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.observe.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.mapInPandas.html" target="_blank">mapInPandas</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.mapInPandas&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.mapInPandas%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.mapInPandas.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.offset.html" target="_blank">offset</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.offset&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.offset%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.offset.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.orderBy.html" target="_blank">orderBy</a>
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.pandas_api.html" target="_blank">pandas_api</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.persist.html" target="_blank">persist</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.persist&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.persist%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.persist.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.printSchema.html" target="_blank">printSchema</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.printSchema&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.printSchema%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.printSchema.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.randomSplit.html" target="_blank">randomSplit</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.randomSplit&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.randomSplit%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.randomSplit.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.registerTempTable.html" target="_blank">registerTempTable</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.registerTempTable&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.registerTempTable%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.registerTempTable.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.repartitionByRange.html" target="_blank">repartitionByRange</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.repartitionByRange&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.repartitionByRange%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.repartitionByRange.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.repartition.html" target="_blank">repartition</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.repartition&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.repartition%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.repartition.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.replace.html" target="_blank">replace</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.replace&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.replace%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.replace.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.sameSemantics.html" target="_blank">sameSemantics</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.sameSemantics&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.sameSemantics%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.sameSemantics.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.rollup.html" target="_blank">rollup</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.rollup&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.rollup%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.rollup.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.sampleBy.html" target="_blank">sampleBy</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.sampleBy&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.sampleBy%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.sampleBy.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.sample.html" target="_blank">sample</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.sample&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.sample%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.sample.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.select.html" target="_blank">select</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.semanticHash.html" target="_blank">semanticHash</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.semanticHash&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.semanticHash%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.semanticHash.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.selectExpr.html" target="_blank">selectExpr</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.selectExpr&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.selectExpr%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.selectExpr.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.show.html" target="_blank">show</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.sortWithinPartitions.html" target="_blank">sortWithinPartitions</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.sortWithinPartitions&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.sortWithinPartitions%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.sortWithinPartitions.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.subtract.html" target="_blank">subtract</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.subtract&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.subtract%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.subtract.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.summary.html" target="_blank">summary</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.summary&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.summary%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.summary.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.tail.html" target="_blank">tail</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.tail&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.tail%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.tail.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.sort.html" target="_blank">sort</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.take.html" target="_blank">take</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.take&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.take%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.take.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.to.html" target="_blank">to</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.to&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.to%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.to.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.toDF.html" target="_blank">toDF</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.toDF&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.toDF%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.toDF.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.toJSON.html" target="_blank">toJSON</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.toJSON&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.toJSON%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.toJSON.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.toLocalIterator.html" target="_blank">toLocalIterator</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.toLocalIterator&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.toLocalIterator%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.toLocalIterator.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.toPandas.html" target="_blank">toPandas</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.transform.html" target="_blank">transform</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.transform&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.transform%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.transform.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.union.html" target="_blank">union</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.union&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.union%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.union.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.unionAll.html" target="_blank">unionAll</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.unionAll&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.unionAll%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.unionAll.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.unionByName.html" target="_blank">unionByName</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.unionByName&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.unionByName%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.unionByName.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.unpersist.html" target="_blank">unpersist</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.unpersist&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.unpersist%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.unpersist.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.unpivot.html" target="_blank">unpivot</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.unpivot&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.unpivot%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.unpivot.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.where.html" target="_blank">where</a>
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.withColumn.html" target="_blank">withColumn</a>
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.withColumnRenamed.html" target="_blank">withColumnRenamed</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.withColumns.html" target="_blank">withColumns</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.withColumns&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.withColumns%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.withColumns.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.withColumnsRenamed.html" target="_blank">withColumnsRenamed</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.withColumnsRenamed&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.withColumnsRenamed%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.withColumnsRenamed.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.withMetadata.html" target="_blank">withMetadata</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.withMetadata&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.withMetadata%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.withMetadata.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.withWatermark.html" target="_blank">withWatermark</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.withWatermark&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.withWatermark%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.withWatermark.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.DataFrame.writeTo.html" target="_blank">writeTo</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.DataFrame.writeTo&body=Please+implement+feature+%5Bpyspark.sql.DataFrame.writeTo%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.DataFrame.writeTo.html%29' target='_blank'>request feature :simple-github:</a>)


## <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/functions.html" target="_blank">pyspark.sql.functions</a>
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.abs.html" target="_blank">abs</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.acos.html" target="_blank">acos</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.acos&body=Please+implement+feature+%5Bpyspark.sql.functions.acos%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.acos.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.acosh.html" target="_blank">acosh</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.acosh&body=Please+implement+feature+%5Bpyspark.sql.functions.acosh%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.acosh.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.aes_decrypt.html" target="_blank">aes_decrypt</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.aes_decrypt&body=Please+implement+feature+%5Bpyspark.sql.functions.aes_decrypt%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.aes_decrypt.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.aes_encrypt.html" target="_blank">aes_encrypt</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.aes_encrypt&body=Please+implement+feature+%5Bpyspark.sql.functions.aes_encrypt%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.aes_encrypt.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.add_months.html" target="_blank">add_months</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.add_months&body=Please+implement+feature+%5Bpyspark.sql.functions.add_months%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.add_months.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.aggregate.html" target="_blank">aggregate</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.aggregate&body=Please+implement+feature+%5Bpyspark.sql.functions.aggregate%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.aggregate.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.any_value.html" target="_blank">any_value</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.any_value&body=Please+implement+feature+%5Bpyspark.sql.functions.any_value%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.any_value.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.approx_count_distinct.html" target="_blank">approx_count_distinct</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.approx_count_distinct&body=Please+implement+feature+%5Bpyspark.sql.functions.approx_count_distinct%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.approx_count_distinct.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.approx_percentile.html" target="_blank">approx_percentile</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.approx_percentile&body=Please+implement+feature+%5Bpyspark.sql.functions.approx_percentile%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.approx_percentile.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.array.html" target="_blank">array</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.array&body=Please+implement+feature+%5Bpyspark.sql.functions.array%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.array.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.array_agg.html" target="_blank">array_agg</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.array_agg&body=Please+implement+feature+%5Bpyspark.sql.functions.array_agg%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.array_agg.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.array_compact.html" target="_blank">array_compact</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.array_compact&body=Please+implement+feature+%5Bpyspark.sql.functions.array_compact%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.array_compact.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.array_append.html" target="_blank">array_append</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.array_append&body=Please+implement+feature+%5Bpyspark.sql.functions.array_append%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.array_append.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.array_contains.html" target="_blank">array_contains</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.array_contains&body=Please+implement+feature+%5Bpyspark.sql.functions.array_contains%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.array_contains.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.array_distinct.html" target="_blank">array_distinct</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.array_distinct&body=Please+implement+feature+%5Bpyspark.sql.functions.array_distinct%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.array_distinct.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.array_intersect.html" target="_blank">array_intersect</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.array_intersect&body=Please+implement+feature+%5Bpyspark.sql.functions.array_intersect%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.array_intersect.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.array_insert.html" target="_blank">array_insert</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.array_insert&body=Please+implement+feature+%5Bpyspark.sql.functions.array_insert%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.array_insert.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.array_join.html" target="_blank">array_join</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.array_join&body=Please+implement+feature+%5Bpyspark.sql.functions.array_join%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.array_join.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.array_max.html" target="_blank">array_max</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.array_max&body=Please+implement+feature+%5Bpyspark.sql.functions.array_max%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.array_max.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.array_min.html" target="_blank">array_min</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.array_min&body=Please+implement+feature+%5Bpyspark.sql.functions.array_min%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.array_min.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.array_position.html" target="_blank">array_position</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.array_position&body=Please+implement+feature+%5Bpyspark.sql.functions.array_position%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.array_position.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.array_prepend.html" target="_blank">array_prepend</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.array_prepend&body=Please+implement+feature+%5Bpyspark.sql.functions.array_prepend%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.array_prepend.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.array_remove.html" target="_blank">array_remove</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.array_remove&body=Please+implement+feature+%5Bpyspark.sql.functions.array_remove%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.array_remove.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.array_repeat.html" target="_blank">array_repeat</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.array_repeat&body=Please+implement+feature+%5Bpyspark.sql.functions.array_repeat%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.array_repeat.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.array_size.html" target="_blank">array_size</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.array_size&body=Please+implement+feature+%5Bpyspark.sql.functions.array_size%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.array_size.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.array_union.html" target="_blank">array_union</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.array_union&body=Please+implement+feature+%5Bpyspark.sql.functions.array_union%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.array_union.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.arrays_overlap.html" target="_blank">arrays_overlap</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.arrays_overlap&body=Please+implement+feature+%5Bpyspark.sql.functions.arrays_overlap%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.arrays_overlap.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.arrays_zip.html" target="_blank">arrays_zip</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.arrays_zip&body=Please+implement+feature+%5Bpyspark.sql.functions.arrays_zip%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.arrays_zip.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.array_except.html" target="_blank">array_except</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.array_except&body=Please+implement+feature+%5Bpyspark.sql.functions.array_except%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.array_except.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.asc_nulls_first.html" target="_blank">asc_nulls_first</a>
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.asc_nulls_last.html" target="_blank">asc_nulls_last</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.ascii.html" target="_blank">ascii</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.ascii&body=Please+implement+feature+%5Bpyspark.sql.functions.ascii%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.ascii.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.asin.html" target="_blank">asin</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.asin&body=Please+implement+feature+%5Bpyspark.sql.functions.asin%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.asin.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.array_sort.html" target="_blank">array_sort</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.array_sort&body=Please+implement+feature+%5Bpyspark.sql.functions.array_sort%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.array_sort.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.asinh.html" target="_blank">asinh</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.asinh&body=Please+implement+feature+%5Bpyspark.sql.functions.asinh%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.asinh.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.assert_true.html" target="_blank">assert_true</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.assert_true&body=Please+implement+feature+%5Bpyspark.sql.functions.assert_true%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.assert_true.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.atan.html" target="_blank">atan</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.atan&body=Please+implement+feature+%5Bpyspark.sql.functions.atan%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.atan.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.atan2.html" target="_blank">atan2</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.atan2&body=Please+implement+feature+%5Bpyspark.sql.functions.atan2%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.atan2.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.atanh.html" target="_blank">atanh</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.atanh&body=Please+implement+feature+%5Bpyspark.sql.functions.atanh%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.atanh.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.base64.html" target="_blank">base64</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.base64&body=Please+implement+feature+%5Bpyspark.sql.functions.base64%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.base64.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.asc.html" target="_blank">asc</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.bit_and.html" target="_blank">bit_and</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.bit_and&body=Please+implement+feature+%5Bpyspark.sql.functions.bit_and%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.bit_and.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.bit_count.html" target="_blank">bit_count</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.bit_count&body=Please+implement+feature+%5Bpyspark.sql.functions.bit_count%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.bit_count.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.bit_get.html" target="_blank">bit_get</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.bit_get&body=Please+implement+feature+%5Bpyspark.sql.functions.bit_get%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.bit_get.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.bit_length.html" target="_blank">bit_length</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.bit_length&body=Please+implement+feature+%5Bpyspark.sql.functions.bit_length%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.bit_length.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.bit_or.html" target="_blank">bit_or</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.bit_or&body=Please+implement+feature+%5Bpyspark.sql.functions.bit_or%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.bit_or.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.bit_xor.html" target="_blank">bit_xor</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.bit_xor&body=Please+implement+feature+%5Bpyspark.sql.functions.bit_xor%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.bit_xor.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.avg.html" target="_blank">avg</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.avg&body=Please+implement+feature+%5Bpyspark.sql.functions.avg%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.avg.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.bitmap_bit_position.html" target="_blank">bitmap_bit_position</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.bitmap_bit_position&body=Please+implement+feature+%5Bpyspark.sql.functions.bitmap_bit_position%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.bitmap_bit_position.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.bitmap_bucket_number.html" target="_blank">bitmap_bucket_number</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.bitmap_bucket_number&body=Please+implement+feature+%5Bpyspark.sql.functions.bitmap_bucket_number%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.bitmap_bucket_number.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.bitmap_construct_agg.html" target="_blank">bitmap_construct_agg</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.bitmap_construct_agg&body=Please+implement+feature+%5Bpyspark.sql.functions.bitmap_construct_agg%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.bitmap_construct_agg.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.bitmap_count.html" target="_blank">bitmap_count</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.bitmap_count&body=Please+implement+feature+%5Bpyspark.sql.functions.bitmap_count%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.bitmap_count.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.bitmap_or_agg.html" target="_blank">bitmap_or_agg</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.bitmap_or_agg&body=Please+implement+feature+%5Bpyspark.sql.functions.bitmap_or_agg%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.bitmap_or_agg.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.bin.html" target="_blank">bin</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.bin&body=Please+implement+feature+%5Bpyspark.sql.functions.bin%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.bin.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.bitwise_not.html" target="_blank">bitwise_not</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.bitwise_not&body=Please+implement+feature+%5Bpyspark.sql.functions.bitwise_not%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.bitwise_not.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.bool_and.html" target="_blank">bool_and</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.bool_and&body=Please+implement+feature+%5Bpyspark.sql.functions.bool_and%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.bool_and.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.bool_or.html" target="_blank">bool_or</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.bool_or&body=Please+implement+feature+%5Bpyspark.sql.functions.bool_or%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.bool_or.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.broadcast.html" target="_blank">broadcast</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.broadcast&body=Please+implement+feature+%5Bpyspark.sql.functions.broadcast%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.broadcast.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.bround.html" target="_blank">bround</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.bround&body=Please+implement+feature+%5Bpyspark.sql.functions.bround%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.bround.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.btrim.html" target="_blank">btrim</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.btrim&body=Please+implement+feature+%5Bpyspark.sql.functions.btrim%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.btrim.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.call_function.html" target="_blank">call_function</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.call_function&body=Please+implement+feature+%5Bpyspark.sql.functions.call_function%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.call_function.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.call_udf.html" target="_blank">call_udf</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.call_udf&body=Please+implement+feature+%5Bpyspark.sql.functions.call_udf%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.call_udf.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.cardinality.html" target="_blank">cardinality</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.cardinality&body=Please+implement+feature+%5Bpyspark.sql.functions.cardinality%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.cardinality.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.cbrt.html" target="_blank">cbrt</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.cbrt&body=Please+implement+feature+%5Bpyspark.sql.functions.cbrt%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.cbrt.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.ceil.html" target="_blank">ceil</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.ceil&body=Please+implement+feature+%5Bpyspark.sql.functions.ceil%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.ceil.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.char.html" target="_blank">char</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.char&body=Please+implement+feature+%5Bpyspark.sql.functions.char%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.char.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.char_length.html" target="_blank">char_length</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.char_length&body=Please+implement+feature+%5Bpyspark.sql.functions.char_length%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.char_length.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.ceiling.html" target="_blank">ceiling</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.ceiling&body=Please+implement+feature+%5Bpyspark.sql.functions.ceiling%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.ceiling.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.coalesce.html" target="_blank">coalesce</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.character_length.html" target="_blank">character_length</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.character_length&body=Please+implement+feature+%5Bpyspark.sql.functions.character_length%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.character_length.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.col.html" target="_blank">col</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.collect_list.html" target="_blank">collect_list</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.collect_list&body=Please+implement+feature+%5Bpyspark.sql.functions.collect_list%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.collect_list.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.collect_set.html" target="_blank">collect_set</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.collect_set&body=Please+implement+feature+%5Bpyspark.sql.functions.collect_set%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.collect_set.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.column.html" target="_blank">column</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.column&body=Please+implement+feature+%5Bpyspark.sql.functions.column%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.column.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.concat_ws.html" target="_blank">concat_ws</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.concat_ws&body=Please+implement+feature+%5Bpyspark.sql.functions.concat_ws%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.concat_ws.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.concat.html" target="_blank">concat</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.concat&body=Please+implement+feature+%5Bpyspark.sql.functions.concat%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.concat.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.contains.html" target="_blank">contains</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.contains&body=Please+implement+feature+%5Bpyspark.sql.functions.contains%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.contains.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.convert_timezone.html" target="_blank">convert_timezone</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.convert_timezone&body=Please+implement+feature+%5Bpyspark.sql.functions.convert_timezone%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.convert_timezone.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.corr.html" target="_blank">corr</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.corr&body=Please+implement+feature+%5Bpyspark.sql.functions.corr%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.corr.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.conv.html" target="_blank">conv</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.conv&body=Please+implement+feature+%5Bpyspark.sql.functions.conv%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.conv.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.cos.html" target="_blank">cos</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.cos&body=Please+implement+feature+%5Bpyspark.sql.functions.cos%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.cos.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.cosh.html" target="_blank">cosh</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.cosh&body=Please+implement+feature+%5Bpyspark.sql.functions.cosh%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.cosh.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.cot.html" target="_blank">cot</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.cot&body=Please+implement+feature+%5Bpyspark.sql.functions.cot%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.cot.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.count.html" target="_blank">count</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.count_distinct.html" target="_blank">count_distinct</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.count_distinct&body=Please+implement+feature+%5Bpyspark.sql.functions.count_distinct%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.count_distinct.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.count_if.html" target="_blank">count_if</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.count_if&body=Please+implement+feature+%5Bpyspark.sql.functions.count_if%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.count_if.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.count_min_sketch.html" target="_blank">count_min_sketch</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.count_min_sketch&body=Please+implement+feature+%5Bpyspark.sql.functions.count_min_sketch%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.count_min_sketch.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.covar_pop.html" target="_blank">covar_pop</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.covar_pop&body=Please+implement+feature+%5Bpyspark.sql.functions.covar_pop%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.covar_pop.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.covar_samp.html" target="_blank">covar_samp</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.covar_samp&body=Please+implement+feature+%5Bpyspark.sql.functions.covar_samp%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.covar_samp.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.crc32.html" target="_blank">crc32</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.crc32&body=Please+implement+feature+%5Bpyspark.sql.functions.crc32%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.crc32.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.create_map.html" target="_blank">create_map</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.create_map&body=Please+implement+feature+%5Bpyspark.sql.functions.create_map%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.create_map.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.csc.html" target="_blank">csc</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.csc&body=Please+implement+feature+%5Bpyspark.sql.functions.csc%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.csc.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.curdate.html" target="_blank">curdate</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.curdate&body=Please+implement+feature+%5Bpyspark.sql.functions.curdate%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.curdate.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.current_database.html" target="_blank">current_database</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.current_database&body=Please+implement+feature+%5Bpyspark.sql.functions.current_database%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.current_database.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.current_date.html" target="_blank">current_date</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.current_date&body=Please+implement+feature+%5Bpyspark.sql.functions.current_date%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.current_date.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.current_schema.html" target="_blank">current_schema</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.current_schema&body=Please+implement+feature+%5Bpyspark.sql.functions.current_schema%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.current_schema.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.current_timestamp.html" target="_blank">current_timestamp</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.current_timestamp&body=Please+implement+feature+%5Bpyspark.sql.functions.current_timestamp%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.current_timestamp.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.current_timezone.html" target="_blank">current_timezone</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.current_timezone&body=Please+implement+feature+%5Bpyspark.sql.functions.current_timezone%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.current_timezone.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.current_user.html" target="_blank">current_user</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.current_user&body=Please+implement+feature+%5Bpyspark.sql.functions.current_user%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.current_user.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.date_add.html" target="_blank">date_add</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.date_add&body=Please+implement+feature+%5Bpyspark.sql.functions.date_add%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.date_add.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.date_diff.html" target="_blank">date_diff</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.date_diff&body=Please+implement+feature+%5Bpyspark.sql.functions.date_diff%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.date_diff.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.cume_dist.html" target="_blank">cume_dist</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.cume_dist&body=Please+implement+feature+%5Bpyspark.sql.functions.cume_dist%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.cume_dist.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.date_format.html" target="_blank">date_format</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.date_format&body=Please+implement+feature+%5Bpyspark.sql.functions.date_format%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.date_format.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.date_from_unix_date.html" target="_blank">date_from_unix_date</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.date_from_unix_date&body=Please+implement+feature+%5Bpyspark.sql.functions.date_from_unix_date%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.date_from_unix_date.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.date_part.html" target="_blank">date_part</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.date_part&body=Please+implement+feature+%5Bpyspark.sql.functions.date_part%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.date_part.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.current_catalog.html" target="_blank">current_catalog</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.current_catalog&body=Please+implement+feature+%5Bpyspark.sql.functions.current_catalog%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.current_catalog.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.date_sub.html" target="_blank">date_sub</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.date_sub&body=Please+implement+feature+%5Bpyspark.sql.functions.date_sub%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.date_sub.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.date_trunc.html" target="_blank">date_trunc</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.date_trunc&body=Please+implement+feature+%5Bpyspark.sql.functions.date_trunc%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.date_trunc.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.dateadd.html" target="_blank">dateadd</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.dateadd&body=Please+implement+feature+%5Bpyspark.sql.functions.dateadd%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.dateadd.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.day.html" target="_blank">day</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.day&body=Please+implement+feature+%5Bpyspark.sql.functions.day%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.day.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.dayofmonth.html" target="_blank">dayofmonth</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.dayofmonth&body=Please+implement+feature+%5Bpyspark.sql.functions.dayofmonth%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.dayofmonth.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.dayofweek.html" target="_blank">dayofweek</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.dayofweek&body=Please+implement+feature+%5Bpyspark.sql.functions.dayofweek%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.dayofweek.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.dayofyear.html" target="_blank">dayofyear</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.dayofyear&body=Please+implement+feature+%5Bpyspark.sql.functions.dayofyear%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.dayofyear.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.datediff.html" target="_blank">datediff</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.datediff&body=Please+implement+feature+%5Bpyspark.sql.functions.datediff%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.datediff.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.datepart.html" target="_blank">datepart</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.datepart&body=Please+implement+feature+%5Bpyspark.sql.functions.datepart%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.datepart.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.decode.html" target="_blank">decode</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.decode&body=Please+implement+feature+%5Bpyspark.sql.functions.decode%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.decode.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.degrees.html" target="_blank">degrees</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.degrees&body=Please+implement+feature+%5Bpyspark.sql.functions.degrees%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.degrees.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.dense_rank.html" target="_blank">dense_rank</a>
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.desc.html" target="_blank">desc</a>
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.desc_nulls_first.html" target="_blank">desc_nulls_first</a>
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.desc_nulls_last.html" target="_blank">desc_nulls_last</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.e.html" target="_blank">e</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.e&body=Please+implement+feature+%5Bpyspark.sql.functions.e%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.e.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.elt.html" target="_blank">elt</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.elt&body=Please+implement+feature+%5Bpyspark.sql.functions.elt%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.elt.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.encode.html" target="_blank">encode</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.encode&body=Please+implement+feature+%5Bpyspark.sql.functions.encode%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.encode.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.endswith.html" target="_blank">endswith</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.endswith&body=Please+implement+feature+%5Bpyspark.sql.functions.endswith%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.endswith.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.equal_null.html" target="_blank">equal_null</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.equal_null&body=Please+implement+feature+%5Bpyspark.sql.functions.equal_null%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.equal_null.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.every.html" target="_blank">every</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.every&body=Please+implement+feature+%5Bpyspark.sql.functions.every%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.every.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.exists.html" target="_blank">exists</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.exists&body=Please+implement+feature+%5Bpyspark.sql.functions.exists%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.exists.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.exp.html" target="_blank">exp</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.exp&body=Please+implement+feature+%5Bpyspark.sql.functions.exp%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.exp.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.explode.html" target="_blank">explode</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.explode&body=Please+implement+feature+%5Bpyspark.sql.functions.explode%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.explode.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.expm1.html" target="_blank">expm1</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.expm1&body=Please+implement+feature+%5Bpyspark.sql.functions.expm1%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.expm1.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.expr.html" target="_blank">expr</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.expr&body=Please+implement+feature+%5Bpyspark.sql.functions.expr%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.expr.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.extract.html" target="_blank">extract</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.extract&body=Please+implement+feature+%5Bpyspark.sql.functions.extract%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.extract.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.element_at.html" target="_blank">element_at</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.element_at&body=Please+implement+feature+%5Bpyspark.sql.functions.element_at%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.element_at.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.factorial.html" target="_blank">factorial</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.factorial&body=Please+implement+feature+%5Bpyspark.sql.functions.factorial%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.factorial.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.filter.html" target="_blank">filter</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.filter&body=Please+implement+feature+%5Bpyspark.sql.functions.filter%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.filter.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.find_in_set.html" target="_blank">find_in_set</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.find_in_set&body=Please+implement+feature+%5Bpyspark.sql.functions.find_in_set%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.find_in_set.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.first.html" target="_blank">first</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.first&body=Please+implement+feature+%5Bpyspark.sql.functions.first%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.first.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.first_value.html" target="_blank">first_value</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.first_value&body=Please+implement+feature+%5Bpyspark.sql.functions.first_value%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.first_value.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.flatten.html" target="_blank">flatten</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.flatten&body=Please+implement+feature+%5Bpyspark.sql.functions.flatten%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.flatten.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.floor.html" target="_blank">floor</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.floor&body=Please+implement+feature+%5Bpyspark.sql.functions.floor%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.floor.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.forall.html" target="_blank">forall</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.forall&body=Please+implement+feature+%5Bpyspark.sql.functions.forall%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.forall.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.format_number.html" target="_blank">format_number</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.format_number&body=Please+implement+feature+%5Bpyspark.sql.functions.format_number%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.format_number.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.format_string.html" target="_blank">format_string</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.format_string&body=Please+implement+feature+%5Bpyspark.sql.functions.format_string%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.format_string.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.explode_outer.html" target="_blank">explode_outer</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.explode_outer&body=Please+implement+feature+%5Bpyspark.sql.functions.explode_outer%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.explode_outer.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.from_csv.html" target="_blank">from_csv</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.from_csv&body=Please+implement+feature+%5Bpyspark.sql.functions.from_csv%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.from_csv.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.from_json.html" target="_blank">from_json</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.from_json&body=Please+implement+feature+%5Bpyspark.sql.functions.from_json%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.from_json.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.from_utc_timestamp.html" target="_blank">from_utc_timestamp</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.from_utc_timestamp&body=Please+implement+feature+%5Bpyspark.sql.functions.from_utc_timestamp%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.from_utc_timestamp.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.from_unixtime.html" target="_blank">from_unixtime</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.from_unixtime&body=Please+implement+feature+%5Bpyspark.sql.functions.from_unixtime%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.from_unixtime.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.get.html" target="_blank">get</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.get&body=Please+implement+feature+%5Bpyspark.sql.functions.get%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.get.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.get_json_object.html" target="_blank">get_json_object</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.getbit.html" target="_blank">getbit</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.getbit&body=Please+implement+feature+%5Bpyspark.sql.functions.getbit%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.getbit.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.greatest.html" target="_blank">greatest</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.greatest&body=Please+implement+feature+%5Bpyspark.sql.functions.greatest%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.greatest.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.grouping_id.html" target="_blank">grouping_id</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.grouping_id&body=Please+implement+feature+%5Bpyspark.sql.functions.grouping_id%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.grouping_id.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.hash.html" target="_blank">hash</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.hash&body=Please+implement+feature+%5Bpyspark.sql.functions.hash%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.hash.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.grouping.html" target="_blank">grouping</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.grouping&body=Please+implement+feature+%5Bpyspark.sql.functions.grouping%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.grouping.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.hex.html" target="_blank">hex</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.hex&body=Please+implement+feature+%5Bpyspark.sql.functions.hex%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.hex.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.histogram_numeric.html" target="_blank">histogram_numeric</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.histogram_numeric&body=Please+implement+feature+%5Bpyspark.sql.functions.histogram_numeric%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.histogram_numeric.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.hll_sketch_agg.html" target="_blank">hll_sketch_agg</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.hll_sketch_agg&body=Please+implement+feature+%5Bpyspark.sql.functions.hll_sketch_agg%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.hll_sketch_agg.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.hll_sketch_estimate.html" target="_blank">hll_sketch_estimate</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.hll_sketch_estimate&body=Please+implement+feature+%5Bpyspark.sql.functions.hll_sketch_estimate%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.hll_sketch_estimate.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.hll_union.html" target="_blank">hll_union</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.hll_union&body=Please+implement+feature+%5Bpyspark.sql.functions.hll_union%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.hll_union.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.hll_union_agg.html" target="_blank">hll_union_agg</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.hll_union_agg&body=Please+implement+feature+%5Bpyspark.sql.functions.hll_union_agg%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.hll_union_agg.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.hour.html" target="_blank">hour</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.hour&body=Please+implement+feature+%5Bpyspark.sql.functions.hour%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.hour.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.hypot.html" target="_blank">hypot</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.hypot&body=Please+implement+feature+%5Bpyspark.sql.functions.hypot%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.hypot.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.ifnull.html" target="_blank">ifnull</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.ifnull&body=Please+implement+feature+%5Bpyspark.sql.functions.ifnull%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.ifnull.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.ilike.html" target="_blank">ilike</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.ilike&body=Please+implement+feature+%5Bpyspark.sql.functions.ilike%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.ilike.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.initcap.html" target="_blank">initcap</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.initcap&body=Please+implement+feature+%5Bpyspark.sql.functions.initcap%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.initcap.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.inline.html" target="_blank">inline</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.inline&body=Please+implement+feature+%5Bpyspark.sql.functions.inline%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.inline.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.inline_outer.html" target="_blank">inline_outer</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.inline_outer&body=Please+implement+feature+%5Bpyspark.sql.functions.inline_outer%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.inline_outer.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.input_file_block_length.html" target="_blank">input_file_block_length</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.input_file_block_length&body=Please+implement+feature+%5Bpyspark.sql.functions.input_file_block_length%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.input_file_block_length.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.input_file_block_start.html" target="_blank">input_file_block_start</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.input_file_block_start&body=Please+implement+feature+%5Bpyspark.sql.functions.input_file_block_start%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.input_file_block_start.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.input_file_name.html" target="_blank">input_file_name</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.input_file_name&body=Please+implement+feature+%5Bpyspark.sql.functions.input_file_name%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.input_file_name.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.instr.html" target="_blank">instr</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.instr&body=Please+implement+feature+%5Bpyspark.sql.functions.instr%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.instr.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.isnan.html" target="_blank">isnan</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.isnan&body=Please+implement+feature+%5Bpyspark.sql.functions.isnan%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.isnan.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.isnotnull.html" target="_blank">isnotnull</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.isnotnull&body=Please+implement+feature+%5Bpyspark.sql.functions.isnotnull%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.isnotnull.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.isnull.html" target="_blank">isnull</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.isnull&body=Please+implement+feature+%5Bpyspark.sql.functions.isnull%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.isnull.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.json_array_length.html" target="_blank">json_array_length</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.json_array_length&body=Please+implement+feature+%5Bpyspark.sql.functions.json_array_length%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.json_array_length.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.java_method.html" target="_blank">java_method</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.java_method&body=Please+implement+feature+%5Bpyspark.sql.functions.java_method%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.java_method.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.kurtosis.html" target="_blank">kurtosis</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.kurtosis&body=Please+implement+feature+%5Bpyspark.sql.functions.kurtosis%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.kurtosis.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.json_tuple.html" target="_blank">json_tuple</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.json_tuple&body=Please+implement+feature+%5Bpyspark.sql.functions.json_tuple%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.json_tuple.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.lag.html" target="_blank">lag</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.lag&body=Please+implement+feature+%5Bpyspark.sql.functions.lag%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.lag.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.last.html" target="_blank">last</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.last&body=Please+implement+feature+%5Bpyspark.sql.functions.last%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.last.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.last_value.html" target="_blank">last_value</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.last_value&body=Please+implement+feature+%5Bpyspark.sql.functions.last_value%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.last_value.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.lcase.html" target="_blank">lcase</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.lcase&body=Please+implement+feature+%5Bpyspark.sql.functions.lcase%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.lcase.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.lead.html" target="_blank">lead</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.lead&body=Please+implement+feature+%5Bpyspark.sql.functions.lead%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.lead.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.last_day.html" target="_blank">last_day</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.last_day&body=Please+implement+feature+%5Bpyspark.sql.functions.last_day%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.last_day.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.least.html" target="_blank">least</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.least&body=Please+implement+feature+%5Bpyspark.sql.functions.least%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.least.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.left.html" target="_blank">left</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.left&body=Please+implement+feature+%5Bpyspark.sql.functions.left%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.left.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.length.html" target="_blank">length</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.levenshtein.html" target="_blank">levenshtein</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.levenshtein&body=Please+implement+feature+%5Bpyspark.sql.functions.levenshtein%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.levenshtein.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.like.html" target="_blank">like</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.like&body=Please+implement+feature+%5Bpyspark.sql.functions.like%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.like.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.lit.html" target="_blank">lit</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.ln.html" target="_blank">ln</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.ln&body=Please+implement+feature+%5Bpyspark.sql.functions.ln%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.ln.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.localtimestamp.html" target="_blank">localtimestamp</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.localtimestamp&body=Please+implement+feature+%5Bpyspark.sql.functions.localtimestamp%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.localtimestamp.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.locate.html" target="_blank">locate</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.locate&body=Please+implement+feature+%5Bpyspark.sql.functions.locate%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.locate.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.log.html" target="_blank">log</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.log&body=Please+implement+feature+%5Bpyspark.sql.functions.log%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.log.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.json_object_keys.html" target="_blank">json_object_keys</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.json_object_keys&body=Please+implement+feature+%5Bpyspark.sql.functions.json_object_keys%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.json_object_keys.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.log10.html" target="_blank">log10</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.log10&body=Please+implement+feature+%5Bpyspark.sql.functions.log10%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.log10.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.log1p.html" target="_blank">log1p</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.log1p&body=Please+implement+feature+%5Bpyspark.sql.functions.log1p%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.log1p.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.lower.html" target="_blank">lower</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.lower&body=Please+implement+feature+%5Bpyspark.sql.functions.lower%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.lower.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.log2.html" target="_blank">log2</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.log2&body=Please+implement+feature+%5Bpyspark.sql.functions.log2%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.log2.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.lpad.html" target="_blank">lpad</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.lpad&body=Please+implement+feature+%5Bpyspark.sql.functions.lpad%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.lpad.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.make_date.html" target="_blank">make_date</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.make_date&body=Please+implement+feature+%5Bpyspark.sql.functions.make_date%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.make_date.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.ltrim.html" target="_blank">ltrim</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.ltrim&body=Please+implement+feature+%5Bpyspark.sql.functions.ltrim%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.ltrim.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.make_dt_interval.html" target="_blank">make_dt_interval</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.make_dt_interval&body=Please+implement+feature+%5Bpyspark.sql.functions.make_dt_interval%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.make_dt_interval.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.make_timestamp.html" target="_blank">make_timestamp</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.make_timestamp&body=Please+implement+feature+%5Bpyspark.sql.functions.make_timestamp%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.make_timestamp.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.make_interval.html" target="_blank">make_interval</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.make_interval&body=Please+implement+feature+%5Bpyspark.sql.functions.make_interval%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.make_interval.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.make_timestamp_ltz.html" target="_blank">make_timestamp_ltz</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.make_timestamp_ltz&body=Please+implement+feature+%5Bpyspark.sql.functions.make_timestamp_ltz%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.make_timestamp_ltz.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.make_ym_interval.html" target="_blank">make_ym_interval</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.make_ym_interval&body=Please+implement+feature+%5Bpyspark.sql.functions.make_ym_interval%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.make_ym_interval.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.make_timestamp_ntz.html" target="_blank">make_timestamp_ntz</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.make_timestamp_ntz&body=Please+implement+feature+%5Bpyspark.sql.functions.make_timestamp_ntz%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.make_timestamp_ntz.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.map_concat.html" target="_blank">map_concat</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.map_concat&body=Please+implement+feature+%5Bpyspark.sql.functions.map_concat%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.map_concat.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.map_contains_key.html" target="_blank">map_contains_key</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.map_contains_key&body=Please+implement+feature+%5Bpyspark.sql.functions.map_contains_key%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.map_contains_key.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.map_filter.html" target="_blank">map_filter</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.map_filter&body=Please+implement+feature+%5Bpyspark.sql.functions.map_filter%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.map_filter.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.map_from_arrays.html" target="_blank">map_from_arrays</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.map_from_arrays&body=Please+implement+feature+%5Bpyspark.sql.functions.map_from_arrays%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.map_from_arrays.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.map_from_entries.html" target="_blank">map_from_entries</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.map_from_entries&body=Please+implement+feature+%5Bpyspark.sql.functions.map_from_entries%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.map_from_entries.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.map_keys.html" target="_blank">map_keys</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.map_keys&body=Please+implement+feature+%5Bpyspark.sql.functions.map_keys%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.map_keys.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.map_values.html" target="_blank">map_values</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.map_values&body=Please+implement+feature+%5Bpyspark.sql.functions.map_values%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.map_values.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.map_zip_with.html" target="_blank">map_zip_with</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.map_zip_with&body=Please+implement+feature+%5Bpyspark.sql.functions.map_zip_with%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.map_zip_with.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.mask.html" target="_blank">mask</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.mask&body=Please+implement+feature+%5Bpyspark.sql.functions.mask%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.mask.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.max.html" target="_blank">max</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.max_by.html" target="_blank">max_by</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.max_by&body=Please+implement+feature+%5Bpyspark.sql.functions.max_by%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.max_by.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.map_entries.html" target="_blank">map_entries</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.map_entries&body=Please+implement+feature+%5Bpyspark.sql.functions.map_entries%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.map_entries.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.median.html" target="_blank">median</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.median&body=Please+implement+feature+%5Bpyspark.sql.functions.median%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.median.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.min.html" target="_blank">min</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.md5.html" target="_blank">md5</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.md5&body=Please+implement+feature+%5Bpyspark.sql.functions.md5%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.md5.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.min_by.html" target="_blank">min_by</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.min_by&body=Please+implement+feature+%5Bpyspark.sql.functions.min_by%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.min_by.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.minute.html" target="_blank">minute</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.minute&body=Please+implement+feature+%5Bpyspark.sql.functions.minute%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.minute.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.mode.html" target="_blank">mode</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.mode&body=Please+implement+feature+%5Bpyspark.sql.functions.mode%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.mode.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.monotonically_increasing_id.html" target="_blank">monotonically_increasing_id</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.monotonically_increasing_id&body=Please+implement+feature+%5Bpyspark.sql.functions.monotonically_increasing_id%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.monotonically_increasing_id.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.month.html" target="_blank">month</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.month&body=Please+implement+feature+%5Bpyspark.sql.functions.month%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.month.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.months_between.html" target="_blank">months_between</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.months_between&body=Please+implement+feature+%5Bpyspark.sql.functions.months_between%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.months_between.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.named_struct.html" target="_blank">named_struct</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.named_struct&body=Please+implement+feature+%5Bpyspark.sql.functions.named_struct%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.named_struct.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.nanvl.html" target="_blank">nanvl</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.nanvl&body=Please+implement+feature+%5Bpyspark.sql.functions.nanvl%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.nanvl.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.negative.html" target="_blank">negative</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.negative&body=Please+implement+feature+%5Bpyspark.sql.functions.negative%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.negative.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.negate.html" target="_blank">negate</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.negate&body=Please+implement+feature+%5Bpyspark.sql.functions.negate%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.negate.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.now.html" target="_blank">now</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.now&body=Please+implement+feature+%5Bpyspark.sql.functions.now%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.now.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.next_day.html" target="_blank">next_day</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.next_day&body=Please+implement+feature+%5Bpyspark.sql.functions.next_day%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.next_day.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.nth_value.html" target="_blank">nth_value</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.nth_value&body=Please+implement+feature+%5Bpyspark.sql.functions.nth_value%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.nth_value.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.ntile.html" target="_blank">ntile</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.ntile&body=Please+implement+feature+%5Bpyspark.sql.functions.ntile%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.ntile.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.nullif.html" target="_blank">nullif</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.nullif&body=Please+implement+feature+%5Bpyspark.sql.functions.nullif%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.nullif.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.nvl.html" target="_blank">nvl</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.nvl&body=Please+implement+feature+%5Bpyspark.sql.functions.nvl%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.nvl.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.nvl2.html" target="_blank">nvl2</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.nvl2&body=Please+implement+feature+%5Bpyspark.sql.functions.nvl2%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.nvl2.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.octet_length.html" target="_blank">octet_length</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.octet_length&body=Please+implement+feature+%5Bpyspark.sql.functions.octet_length%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.octet_length.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.overlay.html" target="_blank">overlay</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.overlay&body=Please+implement+feature+%5Bpyspark.sql.functions.overlay%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.overlay.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.pandas_udf.html" target="_blank">pandas_udf</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.pandas_udf&body=Please+implement+feature+%5Bpyspark.sql.functions.pandas_udf%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.pandas_udf.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.parse_url.html" target="_blank">parse_url</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.parse_url&body=Please+implement+feature+%5Bpyspark.sql.functions.parse_url%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.parse_url.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.percent_rank.html" target="_blank">percent_rank</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.percent_rank&body=Please+implement+feature+%5Bpyspark.sql.functions.percent_rank%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.percent_rank.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.percentile.html" target="_blank">percentile</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.percentile&body=Please+implement+feature+%5Bpyspark.sql.functions.percentile%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.percentile.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.percentile_approx.html" target="_blank">percentile_approx</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.percentile_approx&body=Please+implement+feature+%5Bpyspark.sql.functions.percentile_approx%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.percentile_approx.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.pi.html" target="_blank">pi</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.pi&body=Please+implement+feature+%5Bpyspark.sql.functions.pi%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.pi.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.pmod.html" target="_blank">pmod</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.pmod&body=Please+implement+feature+%5Bpyspark.sql.functions.pmod%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.pmod.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.posexplode.html" target="_blank">posexplode</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.posexplode&body=Please+implement+feature+%5Bpyspark.sql.functions.posexplode%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.posexplode.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.posexplode_outer.html" target="_blank">posexplode_outer</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.posexplode_outer&body=Please+implement+feature+%5Bpyspark.sql.functions.posexplode_outer%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.posexplode_outer.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.mean.html" target="_blank">mean</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.position.html" target="_blank">position</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.position&body=Please+implement+feature+%5Bpyspark.sql.functions.position%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.position.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.positive.html" target="_blank">positive</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.positive&body=Please+implement+feature+%5Bpyspark.sql.functions.positive%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.positive.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.pow.html" target="_blank">pow</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.pow&body=Please+implement+feature+%5Bpyspark.sql.functions.pow%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.pow.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.power.html" target="_blank">power</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.power&body=Please+implement+feature+%5Bpyspark.sql.functions.power%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.power.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.printf.html" target="_blank">printf</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.printf&body=Please+implement+feature+%5Bpyspark.sql.functions.printf%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.printf.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.quarter.html" target="_blank">quarter</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.quarter&body=Please+implement+feature+%5Bpyspark.sql.functions.quarter%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.quarter.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.product.html" target="_blank">product</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.product&body=Please+implement+feature+%5Bpyspark.sql.functions.product%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.product.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.radians.html" target="_blank">radians</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.radians&body=Please+implement+feature+%5Bpyspark.sql.functions.radians%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.radians.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.rand.html" target="_blank">rand</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.rand&body=Please+implement+feature+%5Bpyspark.sql.functions.rand%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.rand.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.raise_error.html" target="_blank">raise_error</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.raise_error&body=Please+implement+feature+%5Bpyspark.sql.functions.raise_error%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.raise_error.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.randn.html" target="_blank">randn</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.randn&body=Please+implement+feature+%5Bpyspark.sql.functions.randn%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.randn.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.rank.html" target="_blank">rank</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.reduce.html" target="_blank">reduce</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.reduce&body=Please+implement+feature+%5Bpyspark.sql.functions.reduce%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.reduce.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.regexp_count.html" target="_blank">regexp_count</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.regexp_count&body=Please+implement+feature+%5Bpyspark.sql.functions.regexp_count%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.regexp_count.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.regexp.html" target="_blank">regexp</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.regexp&body=Please+implement+feature+%5Bpyspark.sql.functions.regexp%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.regexp.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.regexp_extract_all.html" target="_blank">regexp_extract_all</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.regexp_extract_all&body=Please+implement+feature+%5Bpyspark.sql.functions.regexp_extract_all%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.regexp_extract_all.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.regexp_extract.html" target="_blank">regexp_extract</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.regexp_extract&body=Please+implement+feature+%5Bpyspark.sql.functions.regexp_extract%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.regexp_extract.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.regexp_instr.html" target="_blank">regexp_instr</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.regexp_instr&body=Please+implement+feature+%5Bpyspark.sql.functions.regexp_instr%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.regexp_instr.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.regexp_like.html" target="_blank">regexp_like</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.regexp_like&body=Please+implement+feature+%5Bpyspark.sql.functions.regexp_like%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.regexp_like.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.regexp_replace.html" target="_blank">regexp_replace</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.regexp_substr.html" target="_blank">regexp_substr</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.regexp_substr&body=Please+implement+feature+%5Bpyspark.sql.functions.regexp_substr%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.regexp_substr.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.regr_avgx.html" target="_blank">regr_avgx</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.regr_avgx&body=Please+implement+feature+%5Bpyspark.sql.functions.regr_avgx%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.regr_avgx.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.regr_avgy.html" target="_blank">regr_avgy</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.regr_avgy&body=Please+implement+feature+%5Bpyspark.sql.functions.regr_avgy%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.regr_avgy.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.regr_count.html" target="_blank">regr_count</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.regr_count&body=Please+implement+feature+%5Bpyspark.sql.functions.regr_count%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.regr_count.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.regr_intercept.html" target="_blank">regr_intercept</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.regr_intercept&body=Please+implement+feature+%5Bpyspark.sql.functions.regr_intercept%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.regr_intercept.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.regr_r2.html" target="_blank">regr_r2</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.regr_r2&body=Please+implement+feature+%5Bpyspark.sql.functions.regr_r2%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.regr_r2.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.regr_slope.html" target="_blank">regr_slope</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.regr_slope&body=Please+implement+feature+%5Bpyspark.sql.functions.regr_slope%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.regr_slope.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.regr_sxx.html" target="_blank">regr_sxx</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.regr_sxx&body=Please+implement+feature+%5Bpyspark.sql.functions.regr_sxx%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.regr_sxx.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.regr_sxy.html" target="_blank">regr_sxy</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.regr_sxy&body=Please+implement+feature+%5Bpyspark.sql.functions.regr_sxy%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.regr_sxy.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.regr_syy.html" target="_blank">regr_syy</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.regr_syy&body=Please+implement+feature+%5Bpyspark.sql.functions.regr_syy%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.regr_syy.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.repeat.html" target="_blank">repeat</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.repeat&body=Please+implement+feature+%5Bpyspark.sql.functions.repeat%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.repeat.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.replace.html" target="_blank">replace</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.replace&body=Please+implement+feature+%5Bpyspark.sql.functions.replace%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.replace.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.reflect.html" target="_blank">reflect</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.reflect&body=Please+implement+feature+%5Bpyspark.sql.functions.reflect%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.reflect.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.reverse.html" target="_blank">reverse</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.reverse&body=Please+implement+feature+%5Bpyspark.sql.functions.reverse%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.reverse.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.right.html" target="_blank">right</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.right&body=Please+implement+feature+%5Bpyspark.sql.functions.right%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.right.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.rlike.html" target="_blank">rlike</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.rlike&body=Please+implement+feature+%5Bpyspark.sql.functions.rlike%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.rlike.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.rint.html" target="_blank">rint</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.rint&body=Please+implement+feature+%5Bpyspark.sql.functions.rint%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.rint.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.rpad.html" target="_blank">rpad</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.rpad&body=Please+implement+feature+%5Bpyspark.sql.functions.rpad%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.rpad.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.row_number.html" target="_blank">row_number</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.rtrim.html" target="_blank">rtrim</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.rtrim&body=Please+implement+feature+%5Bpyspark.sql.functions.rtrim%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.rtrim.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.schema_of_csv.html" target="_blank">schema_of_csv</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.schema_of_csv&body=Please+implement+feature+%5Bpyspark.sql.functions.schema_of_csv%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.schema_of_csv.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.schema_of_json.html" target="_blank">schema_of_json</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.schema_of_json&body=Please+implement+feature+%5Bpyspark.sql.functions.schema_of_json%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.schema_of_json.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.sec.html" target="_blank">sec</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.sec&body=Please+implement+feature+%5Bpyspark.sql.functions.sec%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.sec.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.second.html" target="_blank">second</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.second&body=Please+implement+feature+%5Bpyspark.sql.functions.second%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.second.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.sentences.html" target="_blank">sentences</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.sentences&body=Please+implement+feature+%5Bpyspark.sql.functions.sentences%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.sentences.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.sequence.html" target="_blank">sequence</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.sequence&body=Please+implement+feature+%5Bpyspark.sql.functions.sequence%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.sequence.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.session_window.html" target="_blank">session_window</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.session_window&body=Please+implement+feature+%5Bpyspark.sql.functions.session_window%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.session_window.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.sha.html" target="_blank">sha</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.sha&body=Please+implement+feature+%5Bpyspark.sql.functions.sha%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.sha.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.sha1.html" target="_blank">sha1</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.sha1&body=Please+implement+feature+%5Bpyspark.sql.functions.sha1%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.sha1.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.sha2.html" target="_blank">sha2</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.sha2&body=Please+implement+feature+%5Bpyspark.sql.functions.sha2%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.sha2.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.round.html" target="_blank">round</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.shiftleft.html" target="_blank">shiftleft</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.shiftleft&body=Please+implement+feature+%5Bpyspark.sql.functions.shiftleft%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.shiftleft.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.shiftright.html" target="_blank">shiftright</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.shiftright&body=Please+implement+feature+%5Bpyspark.sql.functions.shiftright%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.shiftright.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.shiftrightunsigned.html" target="_blank">shiftrightunsigned</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.shiftrightunsigned&body=Please+implement+feature+%5Bpyspark.sql.functions.shiftrightunsigned%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.shiftrightunsigned.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.sign.html" target="_blank">sign</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.sign&body=Please+implement+feature+%5Bpyspark.sql.functions.sign%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.sign.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.shuffle.html" target="_blank">shuffle</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.shuffle&body=Please+implement+feature+%5Bpyspark.sql.functions.shuffle%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.shuffle.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.signum.html" target="_blank">signum</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.signum&body=Please+implement+feature+%5Bpyspark.sql.functions.signum%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.signum.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.sinh.html" target="_blank">sinh</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.sinh&body=Please+implement+feature+%5Bpyspark.sql.functions.sinh%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.sinh.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.sin.html" target="_blank">sin</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.sin&body=Please+implement+feature+%5Bpyspark.sql.functions.sin%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.sin.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.size.html" target="_blank">size</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.size&body=Please+implement+feature+%5Bpyspark.sql.functions.size%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.size.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.slice.html" target="_blank">slice</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.slice&body=Please+implement+feature+%5Bpyspark.sql.functions.slice%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.slice.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.some.html" target="_blank">some</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.some&body=Please+implement+feature+%5Bpyspark.sql.functions.some%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.some.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.sort_array.html" target="_blank">sort_array</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.sort_array&body=Please+implement+feature+%5Bpyspark.sql.functions.sort_array%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.sort_array.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.soundex.html" target="_blank">soundex</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.soundex&body=Please+implement+feature+%5Bpyspark.sql.functions.soundex%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.soundex.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.spark_partition_id.html" target="_blank">spark_partition_id</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.spark_partition_id&body=Please+implement+feature+%5Bpyspark.sql.functions.spark_partition_id%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.spark_partition_id.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.split.html" target="_blank">split</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.split&body=Please+implement+feature+%5Bpyspark.sql.functions.split%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.split.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.sqrt.html" target="_blank">sqrt</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.sqrt&body=Please+implement+feature+%5Bpyspark.sql.functions.sqrt%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.sqrt.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.split_part.html" target="_blank">split_part</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.split_part&body=Please+implement+feature+%5Bpyspark.sql.functions.split_part%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.split_part.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.stack.html" target="_blank">stack</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.stack&body=Please+implement+feature+%5Bpyspark.sql.functions.stack%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.stack.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.startswith.html" target="_blank">startswith</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.startswith&body=Please+implement+feature+%5Bpyspark.sql.functions.startswith%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.startswith.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.std.html" target="_blank">std</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.std&body=Please+implement+feature+%5Bpyspark.sql.functions.std%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.std.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.stddev.html" target="_blank">stddev</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.stddev&body=Please+implement+feature+%5Bpyspark.sql.functions.stddev%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.stddev.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.stddev_pop.html" target="_blank">stddev_pop</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.stddev_pop&body=Please+implement+feature+%5Bpyspark.sql.functions.stddev_pop%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.stddev_pop.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.stddev_samp.html" target="_blank">stddev_samp</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.stddev_samp&body=Please+implement+feature+%5Bpyspark.sql.functions.stddev_samp%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.stddev_samp.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.str_to_map.html" target="_blank">str_to_map</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.str_to_map&body=Please+implement+feature+%5Bpyspark.sql.functions.str_to_map%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.str_to_map.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.struct.html" target="_blank">struct</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.struct&body=Please+implement+feature+%5Bpyspark.sql.functions.struct%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.struct.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.substr.html" target="_blank">substr</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.substr&body=Please+implement+feature+%5Bpyspark.sql.functions.substr%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.substr.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.skewness.html" target="_blank">skewness</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.skewness&body=Please+implement+feature+%5Bpyspark.sql.functions.skewness%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.skewness.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.substring.html" target="_blank">substring</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.substring&body=Please+implement+feature+%5Bpyspark.sql.functions.substring%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.substring.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.sum.html" target="_blank">sum</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.sum_distinct.html" target="_blank">sum_distinct</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.sum_distinct&body=Please+implement+feature+%5Bpyspark.sql.functions.sum_distinct%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.sum_distinct.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.tan.html" target="_blank">tan</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.tan&body=Please+implement+feature+%5Bpyspark.sql.functions.tan%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.tan.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.tanh.html" target="_blank">tanh</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.tanh&body=Please+implement+feature+%5Bpyspark.sql.functions.tanh%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.tanh.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.timestamp_micros.html" target="_blank">timestamp_micros</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.timestamp_micros&body=Please+implement+feature+%5Bpyspark.sql.functions.timestamp_micros%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.timestamp_micros.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.timestamp_millis.html" target="_blank">timestamp_millis</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.timestamp_millis&body=Please+implement+feature+%5Bpyspark.sql.functions.timestamp_millis%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.timestamp_millis.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.timestamp_seconds.html" target="_blank">timestamp_seconds</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.timestamp_seconds&body=Please+implement+feature+%5Bpyspark.sql.functions.timestamp_seconds%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.timestamp_seconds.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.to_binary.html" target="_blank">to_binary</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.to_binary&body=Please+implement+feature+%5Bpyspark.sql.functions.to_binary%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.to_binary.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.to_char.html" target="_blank">to_char</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.to_char&body=Please+implement+feature+%5Bpyspark.sql.functions.to_char%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.to_char.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.to_csv.html" target="_blank">to_csv</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.to_csv&body=Please+implement+feature+%5Bpyspark.sql.functions.to_csv%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.to_csv.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.to_date.html" target="_blank">to_date</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.to_date&body=Please+implement+feature+%5Bpyspark.sql.functions.to_date%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.to_date.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.substring_index.html" target="_blank">substring_index</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.substring_index&body=Please+implement+feature+%5Bpyspark.sql.functions.substring_index%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.substring_index.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.to_json.html" target="_blank">to_json</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.to_json&body=Please+implement+feature+%5Bpyspark.sql.functions.to_json%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.to_json.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.to_number.html" target="_blank">to_number</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.to_number&body=Please+implement+feature+%5Bpyspark.sql.functions.to_number%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.to_number.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.to_timestamp.html" target="_blank">to_timestamp</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.to_timestamp_ltz.html" target="_blank">to_timestamp_ltz</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.to_timestamp_ltz&body=Please+implement+feature+%5Bpyspark.sql.functions.to_timestamp_ltz%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.to_timestamp_ltz.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.to_unix_timestamp.html" target="_blank">to_unix_timestamp</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.to_unix_timestamp&body=Please+implement+feature+%5Bpyspark.sql.functions.to_unix_timestamp%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.to_unix_timestamp.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.to_utc_timestamp.html" target="_blank">to_utc_timestamp</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.to_utc_timestamp&body=Please+implement+feature+%5Bpyspark.sql.functions.to_utc_timestamp%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.to_utc_timestamp.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.transform.html" target="_blank">transform</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.transform&body=Please+implement+feature+%5Bpyspark.sql.functions.transform%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.transform.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.to_varchar.html" target="_blank">to_varchar</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.to_varchar&body=Please+implement+feature+%5Bpyspark.sql.functions.to_varchar%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.to_varchar.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.transform_values.html" target="_blank">transform_values</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.transform_values&body=Please+implement+feature+%5Bpyspark.sql.functions.transform_values%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.transform_values.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.translate.html" target="_blank">translate</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.translate&body=Please+implement+feature+%5Bpyspark.sql.functions.translate%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.translate.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.trim.html" target="_blank">trim</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.trim&body=Please+implement+feature+%5Bpyspark.sql.functions.trim%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.trim.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.trunc.html" target="_blank">trunc</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.trunc&body=Please+implement+feature+%5Bpyspark.sql.functions.trunc%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.trunc.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.try_add.html" target="_blank">try_add</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.try_add&body=Please+implement+feature+%5Bpyspark.sql.functions.try_add%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.try_add.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.to_timestamp_ntz.html" target="_blank">to_timestamp_ntz</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.to_timestamp_ntz&body=Please+implement+feature+%5Bpyspark.sql.functions.to_timestamp_ntz%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.to_timestamp_ntz.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.try_aes_decrypt.html" target="_blank">try_aes_decrypt</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.try_aes_decrypt&body=Please+implement+feature+%5Bpyspark.sql.functions.try_aes_decrypt%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.try_aes_decrypt.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.try_avg.html" target="_blank">try_avg</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.try_avg&body=Please+implement+feature+%5Bpyspark.sql.functions.try_avg%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.try_avg.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.try_element_at.html" target="_blank">try_element_at</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.try_element_at&body=Please+implement+feature+%5Bpyspark.sql.functions.try_element_at%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.try_element_at.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.try_divide.html" target="_blank">try_divide</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.try_divide&body=Please+implement+feature+%5Bpyspark.sql.functions.try_divide%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.try_divide.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.try_multiply.html" target="_blank">try_multiply</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.try_multiply&body=Please+implement+feature+%5Bpyspark.sql.functions.try_multiply%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.try_multiply.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.transform_keys.html" target="_blank">transform_keys</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.transform_keys&body=Please+implement+feature+%5Bpyspark.sql.functions.transform_keys%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.transform_keys.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.try_subtract.html" target="_blank">try_subtract</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.try_subtract&body=Please+implement+feature+%5Bpyspark.sql.functions.try_subtract%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.try_subtract.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.try_sum.html" target="_blank">try_sum</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.try_sum&body=Please+implement+feature+%5Bpyspark.sql.functions.try_sum%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.try_sum.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.try_to_number.html" target="_blank">try_to_number</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.try_to_number&body=Please+implement+feature+%5Bpyspark.sql.functions.try_to_number%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.try_to_number.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.try_to_binary.html" target="_blank">try_to_binary</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.try_to_binary&body=Please+implement+feature+%5Bpyspark.sql.functions.try_to_binary%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.try_to_binary.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.typeof.html" target="_blank">typeof</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.typeof&body=Please+implement+feature+%5Bpyspark.sql.functions.typeof%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.typeof.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.ucase.html" target="_blank">ucase</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.ucase&body=Please+implement+feature+%5Bpyspark.sql.functions.ucase%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.ucase.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.udf.html" target="_blank">udf</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.udf&body=Please+implement+feature+%5Bpyspark.sql.functions.udf%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.udf.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.udtf.html" target="_blank">udtf</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.udtf&body=Please+implement+feature+%5Bpyspark.sql.functions.udtf%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.udtf.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.unbase64.html" target="_blank">unbase64</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.unbase64&body=Please+implement+feature+%5Bpyspark.sql.functions.unbase64%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.unbase64.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.unhex.html" target="_blank">unhex</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.unhex&body=Please+implement+feature+%5Bpyspark.sql.functions.unhex%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.unhex.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.unix_date.html" target="_blank">unix_date</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.unix_date&body=Please+implement+feature+%5Bpyspark.sql.functions.unix_date%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.unix_date.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.unix_micros.html" target="_blank">unix_micros</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.unix_micros&body=Please+implement+feature+%5Bpyspark.sql.functions.unix_micros%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.unix_micros.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.unix_millis.html" target="_blank">unix_millis</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.unix_millis&body=Please+implement+feature+%5Bpyspark.sql.functions.unix_millis%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.unix_millis.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.unix_seconds.html" target="_blank">unix_seconds</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.unix_seconds&body=Please+implement+feature+%5Bpyspark.sql.functions.unix_seconds%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.unix_seconds.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.unwrap_udt.html" target="_blank">unwrap_udt</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.unwrap_udt&body=Please+implement+feature+%5Bpyspark.sql.functions.unwrap_udt%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.unwrap_udt.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.upper.html" target="_blank">upper</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.upper&body=Please+implement+feature+%5Bpyspark.sql.functions.upper%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.upper.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.try_to_timestamp.html" target="_blank">try_to_timestamp</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.try_to_timestamp&body=Please+implement+feature+%5Bpyspark.sql.functions.try_to_timestamp%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.try_to_timestamp.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.url_encode.html" target="_blank">url_encode</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.url_encode&body=Please+implement+feature+%5Bpyspark.sql.functions.url_encode%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.url_encode.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.user.html" target="_blank">user</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.user&body=Please+implement+feature+%5Bpyspark.sql.functions.user%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.user.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.var_pop.html" target="_blank">var_pop</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.var_pop&body=Please+implement+feature+%5Bpyspark.sql.functions.var_pop%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.var_pop.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.var_samp.html" target="_blank">var_samp</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.var_samp&body=Please+implement+feature+%5Bpyspark.sql.functions.var_samp%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.var_samp.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.variance.html" target="_blank">variance</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.variance&body=Please+implement+feature+%5Bpyspark.sql.functions.variance%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.variance.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.version.html" target="_blank">version</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.version&body=Please+implement+feature+%5Bpyspark.sql.functions.version%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.version.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.unix_timestamp.html" target="_blank">unix_timestamp</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.unix_timestamp&body=Please+implement+feature+%5Bpyspark.sql.functions.unix_timestamp%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.unix_timestamp.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.weekday.html" target="_blank">weekday</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.weekday&body=Please+implement+feature+%5Bpyspark.sql.functions.weekday%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.weekday.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.weekofyear.html" target="_blank">weekofyear</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.weekofyear&body=Please+implement+feature+%5Bpyspark.sql.functions.weekofyear%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.weekofyear.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.when.html" target="_blank">when</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.width_bucket.html" target="_blank">width_bucket</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.width_bucket&body=Please+implement+feature+%5Bpyspark.sql.functions.width_bucket%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.width_bucket.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.window.html" target="_blank">window</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.window&body=Please+implement+feature+%5Bpyspark.sql.functions.window%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.window.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.window_time.html" target="_blank">window_time</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.window_time&body=Please+implement+feature+%5Bpyspark.sql.functions.window_time%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.window_time.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.url_decode.html" target="_blank">url_decode</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.url_decode&body=Please+implement+feature+%5Bpyspark.sql.functions.url_decode%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.url_decode.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.xpath.html" target="_blank">xpath</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.xpath&body=Please+implement+feature+%5Bpyspark.sql.functions.xpath%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.xpath.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.xpath_boolean.html" target="_blank">xpath_boolean</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.xpath_boolean&body=Please+implement+feature+%5Bpyspark.sql.functions.xpath_boolean%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.xpath_boolean.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.xpath_double.html" target="_blank">xpath_double</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.xpath_double&body=Please+implement+feature+%5Bpyspark.sql.functions.xpath_double%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.xpath_double.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.xpath_float.html" target="_blank">xpath_float</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.xpath_float&body=Please+implement+feature+%5Bpyspark.sql.functions.xpath_float%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.xpath_float.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.xpath_int.html" target="_blank">xpath_int</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.xpath_int&body=Please+implement+feature+%5Bpyspark.sql.functions.xpath_int%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.xpath_int.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.xpath_long.html" target="_blank">xpath_long</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.xpath_long&body=Please+implement+feature+%5Bpyspark.sql.functions.xpath_long%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.xpath_long.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.xpath_number.html" target="_blank">xpath_number</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.xpath_number&body=Please+implement+feature+%5Bpyspark.sql.functions.xpath_number%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.xpath_number.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.xpath_short.html" target="_blank">xpath_short</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.xpath_short&body=Please+implement+feature+%5Bpyspark.sql.functions.xpath_short%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.xpath_short.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.xpath_string.html" target="_blank">xpath_string</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.xpath_string&body=Please+implement+feature+%5Bpyspark.sql.functions.xpath_string%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.xpath_string.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.xxhash64.html" target="_blank">xxhash64</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.xxhash64&body=Please+implement+feature+%5Bpyspark.sql.functions.xxhash64%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.xxhash64.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.year.html" target="_blank">year</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.year&body=Please+implement+feature+%5Bpyspark.sql.functions.year%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.year.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.functions.zip_with.html" target="_blank">zip_with</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.functions.zip_with&body=Please+implement+feature+%5Bpyspark.sql.functions.zip_with%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.functions.zip_with.html%29' target='_blank'>request feature :simple-github:</a>)


## <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/grouping.html" target="_blank">pyspark.sql.GroupedData</a>
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.GroupedData.agg.html" target="_blank">agg</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.GroupedData.applyInPandas.html" target="_blank">applyInPandas</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.GroupedData.applyInPandas&body=Please+implement+feature+%5Bpyspark.sql.GroupedData.applyInPandas%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.GroupedData.applyInPandas.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.GroupedData.apply.html" target="_blank">apply</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.GroupedData.apply&body=Please+implement+feature+%5Bpyspark.sql.GroupedData.apply%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.GroupedData.apply.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.GroupedData.applyInPandasWithState.html" target="_blank">applyInPandasWithState</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.GroupedData.applyInPandasWithState&body=Please+implement+feature+%5Bpyspark.sql.GroupedData.applyInPandasWithState%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.GroupedData.applyInPandasWithState.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.GroupedData.avg.html" target="_blank">avg</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.GroupedData.avg&body=Please+implement+feature+%5Bpyspark.sql.GroupedData.avg%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.GroupedData.avg.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.GroupedData.cogroup.html" target="_blank">cogroup</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.GroupedData.cogroup&body=Please+implement+feature+%5Bpyspark.sql.GroupedData.cogroup%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.GroupedData.cogroup.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.GroupedData.count.html" target="_blank">count</a>
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.GroupedData.mean.html" target="_blank">mean</a>
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.GroupedData.min.html" target="_blank">min</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.GroupedData.pivot.html" target="_blank">pivot</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.GroupedData.pivot&body=Please+implement+feature+%5Bpyspark.sql.GroupedData.pivot%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.GroupedData.pivot.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.GroupedData.max.html" target="_blank">max</a>
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.GroupedData.sum.html" target="_blank">sum</a>


## <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/spark_session.html" target="_blank">pyspark.sql.SparkSession</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.SparkSession.addArtifact.html" target="_blank">addArtifact</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.SparkSession.addArtifact&body=Please+implement+feature+%5Bpyspark.sql.SparkSession.addArtifact%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.SparkSession.addArtifact.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.SparkSession.addTag.html" target="_blank">addTag</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.SparkSession.addTag&body=Please+implement+feature+%5Bpyspark.sql.SparkSession.addTag%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.SparkSession.addTag.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.SparkSession.clearTags.html" target="_blank">clearTags</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.SparkSession.clearTags&body=Please+implement+feature+%5Bpyspark.sql.SparkSession.clearTags%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.SparkSession.clearTags.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.SparkSession.copyFromLocalToFs.html" target="_blank">copyFromLocalToFs</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.SparkSession.copyFromLocalToFs&body=Please+implement+feature+%5Bpyspark.sql.SparkSession.copyFromLocalToFs%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.SparkSession.copyFromLocalToFs.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.SparkSession.createDataFrame.html" target="_blank">createDataFrame</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.SparkSession.getTags.html" target="_blank">getTags</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.SparkSession.getTags&body=Please+implement+feature+%5Bpyspark.sql.SparkSession.getTags%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.SparkSession.getTags.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.SparkSession.interruptAll.html" target="_blank">interruptAll</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.SparkSession.interruptAll&body=Please+implement+feature+%5Bpyspark.sql.SparkSession.interruptAll%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.SparkSession.interruptAll.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.SparkSession.interruptOperation.html" target="_blank">interruptOperation</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.SparkSession.interruptOperation&body=Please+implement+feature+%5Bpyspark.sql.SparkSession.interruptOperation%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.SparkSession.interruptOperation.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.SparkSession.interruptTag.html" target="_blank">interruptTag</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.SparkSession.interruptTag&body=Please+implement+feature+%5Bpyspark.sql.SparkSession.interruptTag%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.SparkSession.interruptTag.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.SparkSession.newSession.html" target="_blank">newSession</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.SparkSession.newSession&body=Please+implement+feature+%5Bpyspark.sql.SparkSession.newSession%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.SparkSession.newSession.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.SparkSession.range.html" target="_blank">range</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.SparkSession.range&body=Please+implement+feature+%5Bpyspark.sql.SparkSession.range%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.SparkSession.range.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.SparkSession.removeTag.html" target="_blank">removeTag</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.SparkSession.removeTag&body=Please+implement+feature+%5Bpyspark.sql.SparkSession.removeTag%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.SparkSession.removeTag.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.SparkSession.sql.html" target="_blank">sql</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.SparkSession.sql&body=Please+implement+feature+%5Bpyspark.sql.SparkSession.sql%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.SparkSession.sql.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.SparkSession.stop.html" target="_blank">stop</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.SparkSession.stop&body=Please+implement+feature+%5Bpyspark.sql.SparkSession.stop%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.SparkSession.stop.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.SparkSession.table.html" target="_blank">table</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.SparkSession.table&body=Please+implement+feature+%5Bpyspark.sql.SparkSession.table%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.SparkSession.table.html%29' target='_blank'>request feature :simple-github:</a>)
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.SparkSession.addArtifacts.html" target="_blank">addArtifacts</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.SparkSession.addArtifacts&body=Please+implement+feature+%5Bpyspark.sql.SparkSession.addArtifacts%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.SparkSession.addArtifacts.html%29' target='_blank'>request feature :simple-github:</a>)


## <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/window.html" target="_blank">pyspark.sql.Window</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Window.rangeBetween.html" target="_blank">rangeBetween</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Window.rangeBetween&body=Please+implement+feature+%5Bpyspark.sql.Window.rangeBetween%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Window.rangeBetween.html%29' target='_blank'>request feature :simple-github:</a>)
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Window.partitionBy.html" target="_blank">partitionBy</a>
* ✅ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Window.orderBy.html" target="_blank">orderBy</a>
* ❌ <a href="https://spark.apache.org/docs/latest/api/python/reference/pyspark.sql/api/pyspark.sql.Window.rowsBetween.html" target="_blank">rowsBetween</a> (<a href='https://github.com/flypipe/sparkleframe/issues/new?title=%5BPYSPARK_API_REQUEST%5D+add+support+to+pyspark.sql.Window.rowsBetween&body=Please+implement+feature+%5Bpyspark.sql.Window.rowsBetween%5D%28https%3A%2F%2Fspark.apache.org%2Fdocs%2Flatest%2Fapi%2Fpython%2Freference%2Fpyspark.sql%2Fapi%2Fpyspark.sql.Window.rowsBetween.html%29' target='_blank'>request feature :simple-github:</a>)